package com.deadsoftware;

import java.io.IOException;
import javax.microedition.lcdui.Graphics;
import javax.microedition.lcdui.Image;

public class Animation {

    public static Animation createAnimation(Image[] still, int time) {
        
        return new Animation(still, time);
    }
    
    public static Animation createAnimation(Image src, int width, int time) {
        
        int height = src.getHeight();
        int length = src.getWidth() / width;
        Image[] still = new Image[length];
        for(int i = 0; i < length; i++) {
            
            still[i] = Image.createImage(src, i*width, 0, width, height, 0);
        }
        return new Animation(still, time);
    }
    
    public static Animation createAnimation(String path, int width, int time)
            throws IOException {
        
        return Animation.createAnimation(Image.createImage(path), width, time);
    }
    
    private final Image[] mStill;
    private final int mTime;
    private int mPosition;
    private long mLastTime;
    
    private Animation(Image[] still, int time) {
        
        mStill = still;
        mTime = time;
        mPosition = 0;
        mLastTime = System.currentTimeMillis();
    }
    
    public void paint(Graphics graphics, int positionX, int positionY) {
        
        graphics.drawImage(mStill[mPosition], positionX, positionY, 0);
    }
    
    public void next() {
        
        if((System.currentTimeMillis() - mLastTime) < mTime) return;
        mLastTime = System.currentTimeMillis();
        mPosition++;
        if(mPosition >= mStill.length) mPosition = 0;
    }
    
    public void start() {
        
        mLastTime = System.currentTimeMillis();
        mPosition = 0;
    }
}