package com.deadsoftware;

import java.util.Vector;
import javax.microedition.lcdui.Font;
import javax.microedition.lcdui.Graphics;

public final class MultiString {
    
    public static Vector split(String text,char ch) {
        
        Vector result = new Vector();
        StringBuffer stringBuffer = new StringBuffer();
        int length = text.length();
        for(int i = 0; i < length; i++) {
            
            char c = text.charAt(i);
            if(c != ch) {
                
                stringBuffer.append(c);
            } else {
                
                result.addElement(stringBuffer.toString());
                stringBuffer.delete(0, stringBuffer.toString().length());
            }
        }
        result.addElement(stringBuffer.toString());
        return result;
    }
    
    private Font mFont;
    private final String mText;
    private final String[] mString;
    private int mStart;
    private int mEnd;
    
    public MultiString(String original) {
        
        mText=original;
        mFont = Font.getDefaultFont();
        Vector text = split(original, ' ');
        int length = text.size();
        mStart = 0;
        mEnd = length - 1;
        mString = new String[length];
        for(int i = 0; i < length; i++) {
            
            mString[i] = (String) text.elementAt(i);
        }
    }
    
    public void paint(Graphics graphics,
            int positionX,
            int positionY,
            int width,
            int height) {
        
        int posX = positionX;
        for(int i = mStart; i <= mEnd; i++) {
            
            String string = mString[i];
            StringBuffer stringBuffer = new StringBuffer();
            int length = string.length();
            for(int j = 0; j < length; j++) {
                
                char c = string.charAt(j);
                switch(c) {
                    
                    case '\r':
                        posX = positionX;
                        break;
                        
                    case '\n':
                        positionY += mFont.getHeight() + 1;
                        break;
                        
                    default:
                        stringBuffer.append(c);
                }
            }
            string = stringBuffer.toString();
            if((posX + mFont.stringWidth(string + ' ')) > width) {
                
                posX = positionX;
                positionY += mFont.getHeight() + 1;
                if((positionY + mFont.getHeight()) > height) return;
                if(mFont.stringWidth(string) > width) {
                    
                    int x2 = positionX;
                    int size = string.length();
                    for(int j = 0; j < size; j++) {
                        
                        char c = string.charAt(j);
                        if((x2 + mFont.charWidth(c)) > width) {
                            
                            x2 = positionX;
                            positionY += mFont.getHeight() + 1;
                        }
                        graphics.drawChar(c, x2, positionY, 0);
                        x2 += mFont.charWidth(c);
                    }
                    posX += mFont.stringWidth(string + ' ');
                    continue;
                }
            }
            graphics.drawString(string, posX, positionY, 0);
            posX += mFont.stringWidth(string + ' ');
        }
    }
    
    public void setStart(int line, int width) {
        
        int length = mString.length;
        int count = 0;
        int x = 0;
        for(int i = 0; i < length; i++) {
            
            if(line == count) {
                
                mStart = i;
                return;
            }
            if((x + mFont.stringWidth(mString[i] + ' ')) > width) {
                
                count++;
                x = 0;
            }
            x += mFont.stringWidth(mString[i] + ' ');
        }
    }
    
    public void setEnd(int line, int width) {
        
        int length = mString.length;
        int count = 0;
        int x = 0;
        for(int i = 0; i < length; i++) {
            
            if(line == count) {
                
                mEnd = i;
                return;
            }
            if((x + mFont.stringWidth(mString[i] + ' ')) > width) {
                
                count++;
                x = 0;
            }
            x += mFont.stringWidth(mString[i] + ' ');
        }
    }
    
    public int getLength(int width, int height) {
        
        int length = mString.length;
        int result = 0;
        int x = 0;
        for(int i = 0; i < length; i++) {
            
            int size = mString[i].length();
            for(int j = 0; j < size; j++) {
                
                char c = mString[i].charAt(j);
                switch(c) {
                    
                    case '\r':
                        x = 0;
                        break;
                        
                    case '\n':
                        result++;
                        break;
                }
            }
            if((x + mFont.stringWidth(mString[i] + ' ')) > width) {
                
                result++;
                x = 0;
                if(mFont.stringWidth(mString[i]) > width) {
                    
                    int x2 = x;
                    int size2 = mString[i].length();
                    for(int j = 0; j < size2; j++) {
                        
                        char c = mString[i].charAt(j);
                        if((x2 + mFont.charWidth(c)) > width) {
                            
                            x2 = x;
                            result++;
                        }
                        x2 += mFont.charWidth(c);
                    }
                    x2 += mFont.stringWidth(mString[i] + ' ');
                    continue;
                }
            }
            x += mFont.stringWidth(mString[i] + ' ');
        }
        return ++result;
    }
    
    public void setFont(Font font) {
        
        mFont=font;
    }
    
    public String getText() {
        
        return mText;
    }
    
    public Object getObject() {
        
        return getText();
    }
}